"use strict";

function _parserHelper() {
  var data = require("../parser-helper");

  _parserHelper = function _parserHelper() {
    return data;
  };

  return data;
}

/**
 * this file had been forked from https://github.com/pahen/detective-typescript
 */
var Parser = require('@typescript-eslint/typescript-estree');

var Walker = require('node-source-walk');
/**
 * Extracts the dependencies of the supplied TypeScript module
 *
 * @param  {String|Object} src - File's content or AST
 * @param  {Object} options - options to pass to the parser
 * @return {String[]}
 */


module.exports = function (src) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  options.parser = Parser;
  var walker = new Walker(options);
  var dependencies = {};

  var addDependency = function addDependency(dependency) {
    if (!dependencies[dependency]) {
      dependencies[dependency] = {};
    }
  };

  var addImportSpecifier = function addImportSpecifier(dependency, importSpecifier) {
    if (dependencies[dependency].importSpecifiers) {
      dependencies[dependency].importSpecifiers.push(importSpecifier);
    } else {
      dependencies[dependency].importSpecifiers = [importSpecifier];
    }
  };

  var addExportedToImportSpecifier = function addExportedToImportSpecifier(name) {
    Object.keys(dependencies).forEach(function (dependency) {
      if (!dependencies[dependency].importSpecifiers) return;
      var specifier = dependencies[dependency].importSpecifiers.find(function (i) {
        return i.name === name;
      });
      if (specifier) specifier.exported = true;
    });
  };

  if (typeof src === 'undefined') {
    throw new Error('src not given');
  }

  if (src === '') {
    return dependencies;
  }

  walker.walk(src, function (node) {
    switch (node.type) {
      case 'ImportDeclaration':
        if (node.source && node.source.value) {
          var dependency = node.source.value;
          addDependency(dependency);
          node.specifiers.forEach(function (specifier) {
            var specifierValue = {
              isDefault: specifier.type === 'ImportDefaultSpecifier',
              name: specifier.local.name
            };
            addImportSpecifier(dependency, specifierValue);
          });
        }

        break;

      case 'ExportNamedDeclaration':
      case 'ExportAllDeclaration':
        if (node.source && node.source.value) {
          addDependency(node.source.value);
        } else if (node.specifiers && node.specifiers.length) {
          node.specifiers.forEach(function (exportSpecifier) {
            addExportedToImportSpecifier(exportSpecifier.exported.name);
          });
        }

        break;

      case 'ExportDefaultDeclaration':
        addExportedToImportSpecifier(node.declaration.name);
        break;

      case 'TSExternalModuleReference':
        if (node.expression && node.expression.value) {
          addDependency(node.expression.value);
        }

        break;

      case 'CallExpression':
        {
          var value = (0, _parserHelper().getDependenciesFromCallExpression)(node);
          if (value) addDependency(value);
        }
        break;

      case 'MemberExpression':
        {
          var _value = (0, _parserHelper().getDependenciesFromMemberExpression)(node);

          if (_value) addDependency(_value);
        }
        break;

      default:
        break;
    }
  });
  return dependencies;
};
//# sourceMappingURL=index.js.map