"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = extractAngularDependencies;

function _path() {
  var data = _interopRequireDefault(require("path"));

  _path = function _path() {
    return data;
  };

  return data;
}

function _fsExtra() {
  var data = _interopRequireDefault(require("fs-extra"));

  _fsExtra = function _fsExtra() {
    return data;
  };

  return data;
}

function _ngast() {
  var data = require("ngast");

  _ngast = function _ngast() {
    return data;
  };

  return data;
}

function _ramda() {
  var data = _interopRequireDefault(require("ramda"));

  _ramda = function _ramda() {
    return data;
  };

  return data;
}

function _parents() {
  var data = _interopRequireDefault(require("parents"));

  _parents = function _parents() {
    return data;
  };

  return data;
}

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

var debug = require('debug')('angular');

function extractAngularDependencies(workspaceDir, fileName, existingAst) {
  var contextSymbols = _ramda().default.isEmpty(existingAst) ? getAst() : existingAst;
  var directive = contextSymbols.getDirectives().find(function (d) {
    return d.symbol.filePath === fileName;
  });
  return {
    angularAst: contextSymbols,
    angularDependencies: [].concat(_toConsumableArray(getDependenciesFromDecorator()), _toConsumableArray(getDependenciesFromTemplate()))
  };

  function getAst() {
    var resourceResolver = {
      get(url) {
        return _fsExtra().default.readFile(url, 'utf-8');
      },

      getSync(url) {
        return _fsExtra().default.readFileSync(url, 'utf-8');
      }

    };

    var tsconfigPath = _getTsconfigJsonPath();

    var defaultErrorReporter = function defaultErrorReporter(e, pathStr) {
      return console.error(e, pathStr);
    };

    return new (_ngast().ProjectSymbols)(tsconfigPath, resourceResolver, defaultErrorReporter);
  }

  function getDependenciesFromDecorator() {
    var dependencies = [];
    if (!directive) return dependencies;
    var directiveMetadata = directive.getNonResolvedMetadata();
    if (!directiveMetadata.template) return dependencies;
    var templateUrl = directiveMetadata.template.templateUrl;
    var styleUrls = directiveMetadata.template.styleUrls;
    [templateUrl].concat(_toConsumableArray(styleUrls)).forEach(function (url) {
      if (url) {
        // for some reason, the url received is sometimes absolute sometimes relative to the fileName
        var absolutePath = _path().default.isAbsolute(url) ? url : _path().default.join(_path().default.dirname(fileName), url);
        dependencies.push(absolutePath);
      }
    });
    return dependencies;
  }

  function getDependenciesFromTemplate() {
    var dependencies = [];
    if (!directive) return dependencies;
    var directives = contextSymbols.getDirectives();
    if (!directives) return dependencies; // dependencies from templates

    var appSelectors = directives.filter(function (d) {
      return d.isComponent();
    }).map(function (d) {
      return d.getNonResolvedMetadata().selector;
    });
    var templateAst = directive.getTemplateAst().templateAst;
    if (!templateAst) return dependencies;
    var selectorsFromTemplate = templateAst.filter(function (t) {
      return t.name && t.constructor.name === 'ElementAst' && appSelectors.includes(t.name);
    }).map(function (t) {
      return t.name;
    });
    var dependenciesFromTemplate = contextSymbols.getDirectives().filter(function (d) {
      return selectorsFromTemplate.includes(d.getNonResolvedMetadata().selector);
    }).map(function (d) {
      return d.symbol.filePath;
    });
    return dependenciesFromTemplate;
  }
  /**
   * propagate from the workspace dir (or component root dir if imported) backwards to find the
   * tsconfig.json file.
   */


  function _getTsconfigJsonPath() {
    var parentsDirs = (0, _parents().default)(workspaceDir);

    var findPath = function findPath() {
      for (var i = 0; i < parentsDirs.length; i += 1) {
        var config = `${parentsDirs[i]}/tsconfig.json`;

        try {
          if (_fsExtra().default.lstatSync(config).isFile()) {
            return config;
          }
        } catch (e) {// that's fine, try the next directory
        }
      }

      return null;
    };

    var tsConfigPath = findPath();

    if (!tsConfigPath) {
      throw new Error(`failed finding tsconfig.json file starting at "${workspaceDir}" directory`);
    }

    debug(`found tsconfig.json at ${tsConfigPath}`);
    return tsConfigPath;
  }
}
//# sourceMappingURL=extract-dependencies.js.map