"use strict";

function _path() {
  var data = _interopRequireDefault(require("path"));

  _path = function _path() {
    return data;
  };

  return data;
}

function _chai() {
  var data = require("chai");

  _chai = function _chai() {
    return data;
  };

  return data;
}

function _extractDependencies() {
  var data = _interopRequireDefault(require("./extract-dependencies"));

  _extractDependencies = function _extractDependencies() {
    return data;
  };

  return data;
}

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('ExtractAngularDependencies', function () {
  this.timeout(0);
  describe('decorators', function () {
    var fixtureDir = _path().default.join(__dirname, '/../../../../fixtures/angular/decorators');

    var angularDependencies;
    before(function () {
      var fileName = _path().default.join(fixtureDir, 'index.ts');

      var results = (0, _extractDependencies().default)(fixtureDir, fileName, {});
      angularDependencies = results.angularDependencies;
    });
    it('should extract html directives', function () {
      var htmlDirective = _path().default.join(fixtureDir, 'my-template.html');

      (0, _chai().expect)(angularDependencies).to.include(htmlDirective);
    });
    it('should extract css directives', function () {
      var cssDirective = _path().default.join(fixtureDir, 'my-style1.css');

      (0, _chai().expect)(angularDependencies).to.include(cssDirective);
    });
    it('should extract directives entered as variables', function () {
      var directiveAsVar = _path().default.join(fixtureDir, 'my-style2.css');

      (0, _chai().expect)(angularDependencies).to.include(directiveAsVar);
    });
  });
  describe('template dependencies', function () {
    var fixtureDir = _path().default.join(__dirname, '/../../../../fixtures/angular/html-deps');

    var angularDependencies;
    before(function () {
      var fileName = _path().default.join(fixtureDir, 'main-component.ts');

      var results = (0, _extractDependencies().default)(fixtureDir, fileName, {});
      angularDependencies = results.angularDependencies;
    });
    it('should extract the dependencies from the html template', function () {
      var componentDep = _path().default.join(fixtureDir, 'another-component.ts');

      (0, _chai().expect)(angularDependencies).to.include(componentDep);
    });
  });
  describe('missing tsconfig.json file', function () {
    var fixtureDir = _path().default.join(__dirname, '/../../../../fixtures/angular/missing-tsconfig');

    it('should throw an error saying the tsconfig was not found', function () {
      var fileName = _path().default.join(fixtureDir, 'index.ts');

      var func = function func() {
        return (0, _extractDependencies().default)(fixtureDir, fileName, {});
      };

      (0, _chai().expect)(func).to.throw('failed finding tsconfig.json file');
    });
  });
});
//# sourceMappingURL=extract-dependencies.spec.js.map